#[repr(u32)]pub enum AccountType {
Invalid = 0,
Individual = 1,
Multiseat = 2,
GameServer = 3,
AnonGameServer = 4,
Pending = 5,
ContentServer = 6,
Clan = 7,
Chat = 8,
ConsoleUser = 9,
AnonUser = 10,
}Expand description
Steam account types.
SteamIds are used to identify many different types of entities within Steam.
This type represents the type of account associated with a Steam ID.
Variants
Invalid = 0
Invalid user account type.
Individual = 1
Individual user account.
Multiseat = 2
Multiseat (e.g. cybercafe) account.
GameServer = 3
Game server account with a fixed Steam ID.
AnonGameServer = 4
Anonymous game server account.
Pending = 5
Pending account.
ContentServer = 6
Identifies a Steam content server.
Clan = 7
Identifies a Steam clan.
Chat = 8
Identifies a Steam chat.
ConsoleUser = 9
Fake SteamID for local PSN account on PS3 or Live account on 360, etc.
AnonUser = 10
Anoynmous user account.