QueryHandle

Struct QueryHandle 

pub struct QueryHandle { /* private fields */ }
Query handle, to allow for more filtering.

Implementations

Source

impl QueryHandle

pub fn exclude_tag(self, tag: &str) -> QueryHandle

Excludes items with a specific tag.

Panics if tag could not be converted to a CString.

pub fn require_tag(self, tag: &str) -> QueryHandle

Only include items with a specific tag.

Panics if tag could not be converted to a CString.

pub fn any_required(self, any: bool) -> QueryHandle

Sets how to match tags added by require_tag. If true, then any tag may match. If false, all required tags must match.

pub fn language(self, language: &str) -> QueryHandle

Sets the language to return the title and description in for the items on a pending UGC Query.

Defaults to “english”

pub fn allow_cached_response(self, max_age_s: u32) -> QueryHandle

Sets whether results will be returned from the cache for the specific period of time on a pending UGC Query.

Age is in seconds.

pub fn include_long_desc(self, include: bool) -> QueryHandle

Include the full description in results

pub fn include_children(self, include: bool) -> QueryHandle

Include children in results

pub fn include_metadata(self, include: bool) -> QueryHandle

Include metadata in results

pub fn include_additional_previews(self, include: bool) -> QueryHandle

Include additional previews in results

pub fn include_key_value_tags(self, include: bool) -> QueryHandle

Include key value tags in results

pub fn add_required_tag(self, tag: &str) -> QueryHandle

Adds a tag that must be present on all returned items.

pub fn add_excluded_tag(self, tag: &str) -> QueryHandle

Adds a tag that must not be present on any returned items.

pub fn set_return_only_ids(self, return_only_ids: bool) -> QueryHandle

Sets whether to only return the IDs of the items.

pub fn set_return_key_value_tags(self, return_kv_tags: bool) -> QueryHandle

Sets whether to return key value tags with the items.

pub fn set_return_long_description(self, return_long_desc: bool) -> QueryHandle

Sets whether to return the full description of the items.

pub fn set_return_metadata(self, return_metadata: bool) -> QueryHandle

Sets whether to return metadata with the items.

pub fn set_return_children(self, return_children: bool) -> QueryHandle

Sets whether to return children with the items.

pub fn set_return_additional_previews( self, return_additional_previews: bool, ) -> QueryHandle

Sets whether to return additional previews with the items.

pub fn set_return_total_only(self, return_total_only: bool) -> QueryHandle

Sets whether to only return the total number of items.

pub fn set_language(self, language: &str) -> QueryHandle

Sets the language to return the title and description in.

pub fn set_allow_cached_response(self, max_age_seconds: u32) -> QueryHandle

Sets whether results will be returned from the cache.

pub fn set_cloud_file_name_filter(self, file_name: &str) -> QueryHandle

Sets a filter for the cloud file name.

pub fn set_match_any_tag(self, match_any_tag: bool) -> QueryHandle

Sets whether any of the required tags are sufficient for an item to be returned.

pub fn set_search_text(self, search_text: &str) -> QueryHandle

Sets the full-text search string.

pub fn set_ranked_by_trend_days(self, days: u32) -> QueryHandle

Sets the number of days to consider for trending items.

pub fn add_required_key_value_tag(self, key: &str, value: &str) -> QueryHandle

Adds a required key-value tag that must be present on all returned items.

pub fn fetch<F>(self, cb: F)
where F: for<'a> FnOnce(Result<QueryResults<'a>, SteamError>) + 'static + Send,

Sends the query to Steam and calls the provided callback with the results when completed.

pub fn fetch_total<F>(self, cb: F)
where F: Fn(Result<u32, SteamError>) + 'static + Send,

Runs the query, only fetching the total number of results.

pub fn fetch_ids<F>(self, cb: F)
where F: Fn(Result<Vec<PublishedFileId>, SteamError>) + 'static + Send,

Runs the query, only fetching the IDs.