pub struct RemoteStorage { /* private fields */ }Expand description
Access to the steam remote storage interface
Implementations
Sourceimpl RemoteStorage
impl RemoteStorage
Sourcepub fn set_cloud_enabled_for_app(&self, enabled: bool)
pub fn set_cloud_enabled_for_app(&self, enabled: bool)
Toggles whether the steam cloud is enabled for the application
Sourcepub fn is_cloud_enabled_for_app(&self) -> bool
pub fn is_cloud_enabled_for_app(&self) -> bool
Returns whether the steam cloud is enabled for the application
Note
This is independent from the account wide setting
Sourcepub fn is_cloud_enabled_for_account(&self) -> bool
pub fn is_cloud_enabled_for_account(&self) -> bool
Returns whether the steam cloud is enabled for the account
Note
This is independent from the application setting
Sourcepub fn files(&self) -> Vec<SteamFileInfo>
pub fn files(&self) -> Vec<SteamFileInfo>
Returns information about all files in the cloud storage