SteamFile

Struct SteamFile 

pub struct SteamFile { /* private fields */ }
A handle for a possible steam cloud file

Implementations

Source

impl SteamFile

pub fn delete(&self) -> bool

Deletes the file locally and remotely.

Returns whether a file was actually deleted

pub fn forget(&self) -> bool

Deletes the file remotely whilst keeping it locally.

Returns whether a file was actually forgotten

pub fn exists(&self) -> bool

Returns whether a file exists

pub fn is_persisted(&self) -> bool

Returns whether a file is persisted in the steam cloud

pub fn timestamp(&self) -> i64

Returns the timestamp of the file

pub fn set_sync_platforms(&self, platforms: RemoteStoragePlatforms)

Set which platforms the file should be available on

pub fn get_sync_platforms(&self) -> RemoteStoragePlatforms

Returns the platforms the file is available on

pub fn write(self) -> SteamFileWriter

pub fn read(self) -> SteamFileReader

pub fn share(&self, cb: impl FnOnce(Result<u64, SteamError>) + Send + 'static)