pub struct SteamFile { /* private fields */ }Expand description
A handle for a possible steam cloud file
Implementations
Sourceimpl SteamFile
impl SteamFile
Sourcepub fn delete(&self) -> bool
pub fn delete(&self) -> bool
Deletes the file locally and remotely.
Returns whether a file was actually deleted
Sourcepub fn forget(&self) -> bool
pub fn forget(&self) -> bool
Deletes the file remotely whilst keeping it locally.
Returns whether a file was actually forgotten
Sourcepub fn is_persisted(&self) -> bool
pub fn is_persisted(&self) -> bool
Returns whether a file is persisted in the steam cloud
Sourcepub fn set_sync_platforms(&self, platforms: RemoteStoragePlatforms)
pub fn set_sync_platforms(&self, platforms: RemoteStoragePlatforms)
Set which platforms the file should be available on
Sourcepub fn get_sync_platforms(&self) -> RemoteStoragePlatforms
pub fn get_sync_platforms(&self) -> RemoteStoragePlatforms
Returns the platforms the file is available on
pub fn write(self) -> SteamFileWriter ⓘ
pub fn read(self) -> SteamFileReader ⓘ